@@ -83,7 +83,7 @@ HarmonyIntegration <- function(
   scale.layer = 'scale.data',
   new.reduction = 'harmony',
   layers = NULL,
-  npcs = 50L,
+  npcs = NULL,
   key = 'harmony_',
   theta = NULL,
   lambda = NULL,
@@ -94,10 +94,27 @@ HarmonyIntegration <- function(
   max.iter.harmony = 10L,
   max.iter.cluster = 20L,
   epsilon.cluster = 1e-05,
-  epsilon.harmony = 1e-04,
+  epsilon.harmony = 0.01,
   verbose = TRUE,
   ...
-) {
+) {  
+
+  # If the `features` param has been set, inform the user that is ignored.
+  if (!is.null(features)) {
+    inform(
+      "The `features` argument is ignored by `HarmonyIntegration`.",
+      .frequency = "once",
+      .frequency_id = "HarmonyIntegration@features"
+    )
+  }
+  # If the `npcs` param has been set, inform the user that is ignored.
+  if (!is.null(npcs)) {
+    inform(
+      "The `npcs` argument is ignored by `HarmonyIntegration`.",
+      .frequency = "once",
+      .frequency_id = "HarmonyIntegration@npcs"
+    )
+  }
   check_installed(
     pkg = "harmony",
     reason = "for running integration with Harmony"
@@ -107,44 +124,42 @@ HarmonyIntegration <- function(
   } else if (!inherits(x = orig, what = 'DimReduc')) {
     abort(message = "'orig' must be a dimensional reduction")
   }
-  # # Run joint PCA
-  # features <- features %||% Features(x = object, layer = scale.layer)
-  # pca <- RunPCA(
-  #   object = object,
-  #   assay = assay,
-  #   features = features,
-  #   layer = scale.layer,
-  #   npcs = npcs,
-  #   verbose = verbose
-  # )
+
   #create grouping variables
-  groups <- CreateIntegrationGroups(object, layers = layers, scale.layer = scale.layer)
+  groups <- CreateIntegrationGroups(
+    object, 
+    layers = layers, 
+    scale.layer = scale.layer
+  )
+
+  # Set up advanced Harmony options.
+  advanced_options <- harmony::harmony_options(
+    tau = tau,
+    block.size = block.size,
+    max.iter.cluster = max.iter.cluster,
+    epsilon.cluster = epsilon.cluster,
+    epsilon.harmony = epsilon.harmony
+  )
+
   # Run Harmony
-  harmony.embed <- harmony::HarmonyMatrix(
+  harmony.embed <- harmony::RunHarmony(
     data_mat = Embeddings(object = orig),
     meta_data = groups,
     vars_use = 'group',
-    do_pca = FALSE,
-    npcs = 0L,
     theta = theta,
     lambda = lambda,
     sigma = sigma,
     nclust = nclust,
-    tau = tau,
-    block.size = block.size,
-    max.iter.harmony = max.iter.harmony,
-    max.iter.cluster = max.iter.cluster,
-    epsilon.cluster = epsilon.cluster,
-    epsilon.harmony = epsilon.harmony,
+    max_iter = max.iter.harmony,
     return_object = FALSE,
-    verbose = verbose
+    verbose = verbose,
+    .options = advanced_options
   )
-  rownames(x = harmony.embed) <- Cells(x = orig)
+  rownames(harmony.embed) <- Cells(orig)
   # TODO add feature loadings from PCA
   dr <- suppressWarnings(expr = CreateDimReducObject(
     embeddings = harmony.embed,
     key = key,
-    # assay = assay
     assay = DefaultAssay(object = orig)
   ))
   output.list <- list(dr)
@@ -288,7 +303,7 @@ attr(x = CCAIntegration, which = 'Seurat.method') <- 'integration'
 #' @param object A \code{Seurat} object
 #' @param assay Name of \code{Assay} in the \code{Seurat} object
 #' @param layers Names of layers in \code{assay}
-#' @param orig A \link[SeuratObject:DimReduc]{dimensional reduction} to correct
+#' @param orig A \link[SeuratObject]{DimReduc} to correct
 #' @param new.reduction Name of new integrated dimensional reduction
 #' @param reference A reference \code{Seurat} object
 #' @param features A vector of features to use for integration
